/******************************************************************
*
*
* Replication File for Gerber/Huber/Washington 2010
*
* Gregory A. Huber
* gregory.huber@yale.edu
* This version: July 2010
*
******************************************************************/

set more off
set memory 150m
graph set eps logo off
graph set ps logo off
graph set ps tmargin 1

use GerberHuberWashington_APSR_AnonymizedReplicationFile.dta

/******************************************************************
*
*
* Variable codings galore
*
*
******************************************************************/

*bush approval, scaled in direction of lean
gen pre_direct_bushap=.
replace pre_direct_bushap=bushapp if (pid7==5 | pid7==6 | pid7==7)
replace pre_direct_bushap=-bushapp if (pid7==1 | pid7==2 | pid7==3)
label var pre_direct_bushap "Pre Bush Approval rel. pre PID (-2 to 2)"

gen pt_direct_bushap=.
replace pt_direct_bushap=pt_bushapp if (pid7==5 | pid7==6 | pid7==7)
replace pt_direct_bushap=-pt_bushapp if (pid7==1 | pid7==2 | pid7==3)
label var pt_direct_bushap "Post Bush Approval rel. pre PID (-2 to 2)"

*congress approval, scaled in direction of lean
gen pre_direct_congapp=.
replace pre_direct_congapp=-congapp if (pid7==5 | pid7==6 | pid7==7)
replace pre_direct_congapp=congapp if (pid7==1 | pid7==2 | pid7==3)
label var pre_direct_congapp "Pre Cong Approval rel. pre PID (-2 to 2)"

gen pt_direct_congapp=.
replace pt_direct_congapp=-pt_congapp if (pid7==5 | pid7==6 | pid7==7)
replace pt_direct_congapp=pt_congapp if (pid7==1 | pid7==2 | pid7==3)
label var pt_direct_congapp "Post Cong Approval rel. pre PID (-2 to 2)"

*november vote
gen pt_direct_bin_novvote=0 if ((pid7==5 | pid7==6 | pid7==7) | (pid7==1 | pid7==2 | pid7==3)) & pt_novvote~=.
replace pt_direct_bin_novvote=1 if (pt_novvote==-1) & ((pid7==5 | pid7==6 | pid7==7))
replace pt_direct_bin_novvote=1 if (pt_novvote==1) & ((pid7==1 | pid7==2 | pid7==3))
label var pt_direct_bin_novvote "Post Nov. vote aligned with pre PID (0 to 1)"

*past voting history aligned with party id
gen pre_aligned_vh=.
replace pre_aligned_vh=0 if (pid7==1 | pid7==2 | pid7==3) | (pid7==5 | pid7==6 | pid7==7)
replace pre_aligned_vh=1 if (pid7==1 | pid7==2 | pid7==3) & vote2000gore==1
replace pre_aligned_vh=1 if (pid7==5 | pid7==6 | pid7==7) & vote2000bush==1
label var pre_aligned_vh "Pre 2000 vote aligned with pre PID"

gen post_aligned_vh=.
replace post_aligned_vh=0 if (pt_vote2000gore==0 | pt_vote2000gore==1) & ((pid7==1 | pid7==2 | pid7==3) | (pid7==5 | pid7==6 | pid7==7))
replace post_aligned_vh=1 if (pid7==1 | pid7==2 | pid7==3) & pt_vote2000gore==1
replace post_aligned_vh=1 if (pid7==5 | pid7==6 | pid7==7) & pt_vote2000bush==1
label var post_aligned_vh "Post 2000 vote aligned with pre PID"

*economic retrospectives, aligned with party id
gen pre_direct_econ=.
replace pre_direct_econ=-econretro if (pid7==1 | pid7==2 | pid7==3) 
replace pre_direct_econ=econretro if (pid7==5 | pid7==6 | pid7==7) 
label var pre_direct_econ "Pre Econ Retrospective rel. pre PID (-2 to 2)"

gen pre_direct_unemp=.
replace pre_direct_unemp=-unemployment if (pid7==1 | pid7==2 | pid7==3) 
replace pre_direct_unemp=unemployment if (pid7==5 | pid7==6 | pid7==7) 
label var pre_direct_unemp "Pre Econ Unemployment performance rel. pre PID (-2 to 2)"

gen post_direct_econ=.
replace post_direct_econ=-pt_econretro if (pid7==1 | pid7==2 | pid7==3) 
replace post_direct_econ=pt_econretro if (pid7==5 | pid7==6 | pid7==7) 
label var post_direct_econ "Post Econ Retrospective rel. pre PID (-2 to 2)"

gen post_direct_unemp=.
replace post_direct_unemp=-pt_postunemployperf if (pid7==1 | pid7==2 | pid7==3) 
replace post_direct_unemp=pt_postunemployperf if (pid7==5 | pid7==6 | pid7==7) 
label var post_direct_unemp "Post Unemp performance rel. pre PID (-2 to 2)"

*opinion about staying in iraq, aligned with party id
gen post_aligned_iraq=.
replace post_aligned_iraq=-pt_stayiniraq if (pid7==1 | pid7==2 | pid7==3)
replace post_aligned_iraq=pt_stayiniraq if (pid7==5 | pid7==6 | pid7==7)
label var post_aligned_iraq "Post Iraq policy aligned with pre PID"

*opinion about taxing rich, aligned with party id
gen post_aligned_taxrich=.
replace post_aligned_taxrich=pt_taxrich if (pid7==1 | pid7==2 | pid7==3)
replace post_aligned_taxrich=-pt_taxrich if (pid7==5 | pid7==6 | pid7==7)
label var post_aligned_taxrich "Post Taxing rich aligned with pre PID"

*opinion about reagan, carter, gop, and dems, aligned with party id
gen post_aligned_reagan=.
replace post_aligned_reagan=-pt_evalreagan if (pid7==1 | pid7==2 | pid7==3)
replace post_aligned_reagan=pt_evalreagan if (pid7==5 | pid7==6 | pid7==7)
label var post_aligned_reagan "Post Eval of Reagan aligned with pre PID"

gen post_aligned_carter=.
replace post_aligned_carter=pt_evalcarter if (pid7==1 | pid7==2 | pid7==3)
replace post_aligned_carter=-pt_evalcarter if (pid7==5 | pid7==6 | pid7==7)
label var post_aligned_carter "Post Eval of Carter aligned with pre PID"

gen post_aligned_rep=.
replace post_aligned_rep=-pt_evalrep if (pid7==1 | pid7==2 | pid7==3)
replace post_aligned_rep=pt_evalrep if (pid7==5 | pid7==6 | pid7==7)
label var post_aligned_rep "Post Eval of Reps. aligned with pre PID"

gen post_aligned_dem=.
replace post_aligned_dem=pt_evaldem if (pid7==1 | pid7==2 | pid7==3)
replace post_aligned_dem=-pt_evaldem if (pid7==5 | pid7==6 | pid7==7)
label var post_aligned_dem "Post Eval of Dems. aligned with pre PID"

*pre-survey, leaned toward dems
gen pre_lean_dem=(pid7==3)
label var pre_lean_dem "Leaned to Dems in pre-survey"

/******************************************************************
*
* Footnote 11, attrition due to moving/etc.
*
******************************************************************/
bysort R_STRATACOAFILTER: tab pid7 pt_pid7 if pid7==3 | pid7==5 & pt_pid7~=.

/******************************************************************
*
* Footnote 12 requires all strata to give correct answer, not these data
*
******************************************************************/

/******************************************************************
*
* Footnote 13, partisanship after applying footnote 11 restriction
*
******************************************************************/

tab pid7 if R_STRATACOAFILTER==0

/******************************************************************
*
* Retention rates analysis, page 727
*
******************************************************************/

tab pid7 if pid7==3 | pid7==5
tab pid7 if (pid7==3 | pid7==5) & pt_pid7~=.

*same among those with valid addresses/etc.
*
*tab pid7 if (pid7==3 | pid7==5) &  R_STRATACOAFILTER==0
*tab pid7 if (pid7==3 | pid7==5) & pt_pid7~=. &  R_STRATACOAFILTER==0

/******************************************************************
*
* Table A1, Conduct balance analysis
*
******************************************************************/

*Note that the chi2 tests are spit out below and need to be manually edited because they don't vary.

gen chi2=.
gen pvalue=.

tokenize "Lean D;Lean R", parse(";")

forvalues i = 5(2)7 {

di "Strata `i', `1'"

 quietly probit treat age age2 regyear regyearmissing twonames vffemale vfgendermissing voted2006-voted1996 interest votein2000 vote2000bush vote2000gore econretro unemployment bushapp congapp if stratactr==`i' & (R_STRATACOAFILTER==0)
 quietly test age age2 regyear regyearmissing vffemale vfgendermissing voted2006 voted2004 voted2002 voted2000 voted1998 voted1996 interest votein2000 vote2000bush vote2000gore econretro unemployment bushapp congapp
 quietly replace chi2=r(chi2)
 quietly replace pvalue=r(p)

 if `i'==5 {
 outsum age regyear regyearmissing vffemale vfgendermissing twonames voted2006-voted1996 interest votein2000 vote2000bush vote2000gore econretro unemployment bushapp congapp chi2 pvalue if stratactr==`i' & treat==1 & R_STRATACOAFILTER==0 using logs\TableA1.out, replace ctitle("`1', Treatment") bracket
 }
 else {
 outsum age regyear regyearmissing vffemale vfgendermissing twonames voted2006-voted1996 interest votein2000 vote2000bush vote2000gore econretro unemployment bushapp congapp chi2 pvalue if stratactr==`i' & treat==1 & R_STRATACOAFILTER==0 using logs\TableA1, append ctitle("`1', Treatment") bracket
 }
 outsum age regyear regyearmissing vffemale vfgendermissing twonames voted2006-voted1996 interest votein2000 vote2000bush vote2000gore econretro unemployment bushapp congapp chi2 pvalue if stratactr==`i' & treat==0 & R_STRATACOAFILTER==0 using logs\TableA1, append ctitle("`1', Control") bracket

 mac shift
 mac shift

}

/******************************************************************
*
* Table A2: Effect of treatment on attrition (prob. of completing post-survey)
*
******************************************************************/

preserve

keep if strata==13 | strata==15
gen completedpost=0
replace completedpost=1 if pt_pid7~=.

gen pre_ld=0
replace pre_ld=1 if strata==13

gen x_pre_ld=treat*pre_ld
gen x_age=treat*age
gen x_age2=treat*age2
gen x_regyear=treat*regyear
gen x_regyearmissing=treat*regyearmissing
gen x_twonames=treat*twonames
gen x_vffemale=treat*vffemale
gen x_vfgendermissing=treat*vfgendermissing
gen x_voted2006=treat*voted2006
gen x_voted2004=treat*voted2004
gen x_voted2002=treat*voted2002
gen x_voted2000=treat*voted2000
gen x_voted1998=treat*voted1998
gen x_voted1996=treat*voted1996
gen x_interest=treat*interest
gen x_pre_aligned_vh=treat*pre_aligned_vh
gen x_pre_direct_econ=treat*pre_direct_econ
gen x_pre_direct_unemp=treat*pre_direct_unemp
gen x_pre_direct_bushap=treat*pre_direct_bushap
gen x_pre_direct_congapp=treat*pre_direct_congapp

regress completedpost pre_ld age age2 regyear regyearmissing twonames vffemale vfgendermissing voted2006-voted1996 interest pre_aligned_vh pre_direct_econ pre_direct_unemp pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0, robust
outreg using "logs\TableA2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace

regress completedpost pre_ld age age2 regyear regyearmissing twonames vffemale vfgendermissing voted2006-voted1996 interest pre_aligned_vh pre_direct_econ pre_direct_unemp pre_direct_bushap pre_direct_congapp treat x_pre_ld x_age x_age2 x_regyear x_regyearmissing x_twonames x_vffemale x_vfgendermissing x_voted2006 x_voted2004 x_voted2002 x_voted2000 x_voted1998 x_voted1996 x_interest x_pre_aligned_vh x_pre_direct_econ x_pre_direct_unemp x_pre_direct_bushap x_pre_direct_congapp if R_STRATACOAFILTER==0, robust
test treat x_pre_ld x_age x_age2 x_regyear x_regyearmissing x_twonames x_vffemale x_vfgendermissing x_voted2006 x_voted2004 x_voted2002 x_voted2000 x_voted1998 x_voted1996 x_interest x_pre_aligned_vh x_pre_direct_econ x_pre_direct_unemp x_pre_direct_bushap x_pre_direct_congapp 
outreg using "logs\TableA2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append addstat(F-statistic, `r(F)', P-value of Chi2 statistic, `r(p)') 

restore

**********************************************
*
* This analysis, which is discussed on page 735, is the effect of naturalistic changes
*  in partisanship on attitudes
*
**********************************************

log using logs\ObservationBenchmark_ChangeinPIDinControlGrouponAttitudes.txt, text replace 

preserve

gen pt_voteevalalignindex=post_aligned_vh+pt_direct_bin_novvote+post_aligned_rep+post_aligned_dem
gen abspid7=abs(pid7-4)

*post, identified with previously leaning/id party
gen pt_id_with_lean=.
replace pt_id_with_lean=0 if pt_pid7~=. & pid7~=.
replace pt_id_with_lean=1 if (pid7==3 | pid7==2 | pid7==1) & (pt_pid7==1 | pt_pid7==2)
replace pt_id_with_lean=1 if (pid7==5 | pid7==6 | pid7==7) & (pt_pid7==6 | pt_pid7==7)
replace pt_id_with_lean=1 if (pid7==4) & (pt_pid7==4)
label var pt_id_with_lean "Post-ID'ed with pre-survey party"

*post-partyid, scaled in direction of lean
gen pt_direct_pid7=.
replace pt_direct_pid7=pt_pid7 if pid7==5 | pid7==6 | pid7==7
replace pt_direct_pid7=8-pt_pid7 if pid7==1 | pid7==2 | pid7==3
replace pt_direct_pid7=3-abs(pt_pid7-4) if pid7==4
label var pt_direct_pid7 "Post PID rel. to pre-survey identity/lean PID (1=Strongly against to 7=Strongly with)"

keep if pid7~=. & pt_voteevalalignindex~=.

*This block of code is restricted to those in the control group
	table abspid7 if treat==0, c(mean pt_voteevalalignindex)
	tab pt_voteevalalignindex if abspid7==3 & treat==0
	tab pt_voteevalalignindex if abspid7==2 & treat==0
	*To pool the 3's and 2's, we need to deal with the different n's
	gen wt=0 if treat==0
	replace wt=1 if abspid7==3 & treat==0
	replace wt=70/92 if abspid7==2 & treat==0
	tab pt_voteevalalignindex [aweight=wt] if (abspid7==2 | abspid7==3) & treat==0
	tab pt_voteevalalignindex if abspid7==1 & treat==0

	tab abspid7 if treat==0, gen(piddum_)
	regress pt_voteevalalignindex piddum_2 piddum_3 if treat==0
	regress pt_voteevalalignindex piddum_2 piddum_3 if abspid7~=3 & treat==0
	regress pt_voteevalalignindex piddum_2 piddum_3 if abspid7~=2 & treat==0
	regress pt_voteevalalignindex piddum_2 piddum_3 if abspid7~=1 & treat==0

*For this block, sample restrictions are defined in each regression
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp pt_id_with_lean if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) & treat==0, robust
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp pt_direct_pid7 if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) & treat==0, robust
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp pt_id_with_lean if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) & treat==1, robust
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp pt_direct_pid7 if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) & treat==1, robust

restore

log close

/******************************************************************
*
* This code sets common sample to those who completed post-survey and were either leaners or pure independents in the pre-survey
* (We retain pure independents for later analysis of treatment effects on their PID)
*
******************************************************************/

*For leaners, require having completed entire pre-survey
quietly regress pt_pid7 age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pid7 interest votein2000 vote2000bush vote2000gore econretro unemployment bushapp congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
quietly gen usesample=e(sample)
*For pure independents, require having completed only pid measure in both surveys
quietly regress pt_pid7 age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pid7 treat if R_STRATACOAFILTER==0 & (pid7==4), robust
quietly replace usesample=1 if e(sample)
quietly keep if usesample==1

/******************************************************************
*
* Table 1, In text, is experiment flowchart
*
******************************************************************/

/******************************************************************
*
* Table 2, Treatment effect on affiliation, among leaners
*
******************************************************************/

*post, identified with previously leaning/id party
gen pt_id_with_lean=.
replace pt_id_with_lean=0 if pt_pid7~=. & pid7~=.
replace pt_id_with_lean=1 if (pid7==3 | pid7==2 | pid7==1) & (pt_pid7==1 | pt_pid7==2)
replace pt_id_with_lean=1 if (pid7==5 | pid7==6 | pid7==7) & (pt_pid7==6 | pt_pid7==7)
replace pt_id_with_lean=1 if (pid7==4) & (pt_pid7==4)
label var pt_id_with_lean "Post-ID'ed with pre-survey party"

*post-partyid, scaled in direction of lean
gen pt_direct_pid7=.
replace pt_direct_pid7=pt_pid7 if pid7==5 | pid7==6 | pid7==7
replace pt_direct_pid7=8-pt_pid7 if pid7==1 | pid7==2 | pid7==3
replace pt_direct_pid7=3-abs(pt_pid7-4) if pid7==4
label var pt_direct_pid7 "Post PID rel. to pre-survey identity/lean PID (1=Strongly against to 7=Strongly with)"

*Simple cross tabs, both among leaners & pure independents, of treatment effects on relative scaled partisanship measure
tab pt_direct_pid7 treat if (pid7==3 | pid7==5)
tab pt_direct_pid7 treat if (pid7==4)

regress pt_id_with_lean treat pre_lean_dem if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace 

regress pt_id_with_lean treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_id_with_lean treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_id_with_lean treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if (strata==13)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_id_with_lean treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if (strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_direct_pid7 treat pre_lean_dem if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_direct_pid7 treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_direct_pid7 treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_direct_pid7 treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if (strata==13)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress pt_direct_pid7 treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if (strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table2.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

*Graphical representation of change in PID
label define yesno 1 "Sent Mail" 0 "Not Sent Mail"
label values treat yesno
label var pt_pid7 "Post-Survey Party ID (1=SD, 2=WD, 3=LD, 4=I, 5=LR, 6=WR, 7=SR)

twoway (histogram pt_pid7 if strata==13 & R_STRATACOAFILTER==0, discrete fraction start(1)), ytitle(Proportion) xlabel(1(1)7) xtitle("") by(, note("") title("(A) Among Pre-Survey Latent Democrats", size(medium))) scheme(s1mono) graphregion(fcolor(none) ifcolor(none)) plotregion(fcolor(none) ifcolor(none)) name(postpidleand, replace) xsize(6.5) ysize(3) by(treat)
twoway (histogram pt_pid7 if strata==15 & R_STRATACOAFILTER==0, discrete fraction start(1)), ytitle(Proportion) xlabel(1(1)7) by(, note("") title("(B) Among Pre-Survey Latent Republicans", size(medium))) scheme(s1mono) graphregion(fcolor(none) ifcolor(none)) plotregion(fcolor(none) ifcolor(none)) name(postpidleanr, replace) xsize(6.5) ysize(3) by(treat)
graph combine postpidleand postpidleanr, ycommon xcommon cols(1) imargin(zero) caption("Note: By definition, all Latent Democrats (panel A) start at 3 in pre-treatement survey, while all Latent Republicans (panel B) start at 5.", size(tiny))  note("Note: Sample is respondents with measure of partisanship in both surveys, valid addresses, and who had not moved before treatment was applied.", size(tiny)) title(Figure 1: Post-Survey Party Identification, size(medium)) subtitle(By Pre-Survey Party Identification and Whether Sent Mail, size(medium)) scheme(s1mono) graphregion(fcolor(none) ifcolor(none)) plotregion(fcolor(none) ifcolor(none)) xsize(6.5) ysize(6)

graph set ps lmargin 1
graph set ps tmargin 1
graph set ps orientation portrait
graph export logs\Figure1.ps, replace

/******************************************************************
*
* Table 3, Treatment effect on registration and turnout. Regression analysis. Focal sample (Leaners; completed both surveys)
*
******************************************************************/

gen post_reg_lean=.
replace post_reg_lean=0 if pid7~=. & pid7~=4
replace post_reg_lean=1 if (pid7==1 | pid7==2 | pid7==3) & post_dem==1
replace post_reg_lean=1 if (pid7==5 | pid7==6 | pid7==7) & post_rep==1
label var post_reg_lean "Registered with party closest to pre-survey PID"

*Natural change in registration in control group
tab pid7 post_rep if treat==0, row
tab pid7 post_dem if treat==0, row

regress post_reg_lean treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table3.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace 

regress voted2008 treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if (strata==13 | strata==15)  & R_STRATACOAFILTER==0, robust
outreg using "logs\Table3.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress post_dem treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if strata==13 & R_STRATACOAFILTER==0, robust
outreg using "logs\Table3.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress post_rep treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if strata==15 & R_STRATACOAFILTER==0, robust
outreg using "logs\Table3.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress voted2008 treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if strata==13 & R_STRATACOAFILTER==0, robust
outreg using "logs\Table3.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress voted2008 treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if strata==15 & R_STRATACOAFILTER==0, robust
outreg using "logs\Table3.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

/******************************************************************
*
* Table 4, Treatment effect on opinions, among leaners
*
******************************************************************/

gen pt_voteevalalignindex=       post_aligned_vh+pt_direct_bin_novvote+post_aligned_rep+post_aligned_dem
label var pt_voteevalalignindex "Voting and evaluations post-alignment scale"

gen pt_voteevalalignindexwithcb=       post_aligned_vh+pt_direct_bin_novvote+pt_direct_bushap+pt_direct_congapp+post_aligned_rep+post_aligned_dem
label var pt_voteevalalignindexwithcb "Voting and evaluations post-alignment scale adding Congress and Bush"

gen pt_voteevalalignindexwitcbhist=post_aligned_vh+pt_direct_bin_novvote+pt_direct_bushap+pt_direct_congapp+post_aligned_rep+post_aligned_dem+post_aligned_reagan+post_aligned_carter
label var pt_voteevalalignindexwitcbhist "Voting and evaluations post-alignment scale adding Carter and Reagan"

gen pt_policyevalalignindex=post_aligned_iraq+post_aligned_taxrich+post_direct_econ+post_direct_unemp
label var pt_policyevalalignindex "Policy evaluations post-alignment scale"

*Voting and Evals Index
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace ctitle("OLS")

ivregress 2sls pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_id_with_lean = treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (ID with leaning party)")
regress pt_id_with_lean treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) & e(sample)==1, robust
test treat

ivregress 2sls pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_direct_pid7 = treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (7PT ID with leaning party)")
regress pt_direct_pid7 treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) & e(sample)==1, robust
test treat

*With Congress/Bush
regress pt_voteevalalignindexwithcb pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("OLS")

ivregress 2sls pt_voteevalalignindexwithcb pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_id_with_lean = treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (ID with leaning party)")

ivregress 2sls pt_voteevalalignindexwithcb pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_direct_pid7 = treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (7PT ID with leaning party)")

*With Carter/Reagan
regress pt_voteevalalignindexwitcbhist pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("OLS")

ivregress 2sls pt_voteevalalignindexwitcbhist pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_id_with_lean = treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (ID with leaning party)")

ivregress 2sls pt_voteevalalignindexwitcbhist pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_direct_pid7 = treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (7PT ID with leaning party)")

*Policy Evaluations
regress pt_policyevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("OLS")

ivregress 2sls pt_policyevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_id_with_lean = treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (ID with leaning party)")

ivregress 2sls pt_policyevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp (pt_direct_pid7= treat) if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("ATT (7PT ID with leaning party)")

/******************************************************************
*
* Appendix Table A4, Treatment effect on opinions, among leaners, broken down by item
*
******************************************************************/

*Appendix, item by item
tokenize "post_aligned_vh;pt_direct_bin_novvote;post_aligned_rep;post_aligned_dem;pt_direct_bushap;pt_direct_congapp;post_aligned_reagan;post_aligned_carter;post_aligned_iraq;post_aligned_taxrich;post_direct_econ;post_direct_unemp", parse(";")

forvalues i = 1(1)12 {

 preserve

 *set common sample for first 8 and last 4 rows
 if `i'<=8 {
  qui regress  pt_voteevalalignindexwithcb pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
  keep if e(sample)
 }
 else {
  qui regress pt_policyevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
  keep if e(sample)
 }

 if `i'==1 {
  regress `1' pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) ==1, robust
  outreg treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp using "logs\TableA4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace
 } 
 else {
  regress `1' pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) ==1, robust
  outreg using "logs\TableA4.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append
 }

 restore

 mac shift
 mac shift

}

/******************************************************************
*
* Appendix Table A5, Robustness of Treatment effect on opinions, among leaners
*
******************************************************************/

*Baseline analysis
regress pt_voteevalalignindex treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\TableA5.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace

*Pre as index
gen preindex=pre_aligned_vh+pre_direct_unemp+pre_direct_econ+pre_direct_bushap+pre_direct_congapp
label var preindex "Pre alignment index"
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest preindex treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\TableA5.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

*Differenced DV
gen diffdepvar=pt_voteevalalignindex-preindex
label var diffdepvar "Post-alignment index - Pre-alignment index"
regress diffdepvar pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\TableA5.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

*No control for prior opinions
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\TableA5.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

*no controls
regress pt_voteevalalignindex pre_lean_dem treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\TableA5.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

*Subsamples
regress pt_voteevalalignindex treat if R_STRATACOAFILTER==0 & (pid7==3), robust
outreg using "logs\TableA5.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("Latent Dems.")

regress pt_voteevalalignindex treat if R_STRATACOAFILTER==0 & (pid7==5), robust
outreg using "logs\TableA5.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append ctitle("Latent Reps.")

/******************************************************************
*
* Table 5, In text, is mechanisms table
*
******************************************************************/

/******************************************************************
*
* Table 6, Treatment effect on reported interest and behaviors, among leaners
*
******************************************************************/

*Campaign treatment index (does not include ads)
gen treatmentindex=pt_gotmoney+pt_gotface+pt_gotphone+pt_gotmail
label var treatmentindex "Campaign Treatment Index (0-4)"

*Set common sample for this analysis

preserve

quietly regress pt_soughtinfo pt_persuadeothers pt_campaigndonation pt_interest treatmentindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
quietly keep if e(sample)

*Treatments index
regress treatmentindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table6.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace 

*Behavior
regress pt_soughtinfo pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table6.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

regress pt_persuadeothers pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table6.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

regress pt_campaigndonation pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table6.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

*Interest
regress pt_interest pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
outreg using "logs\Table6.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append

/******************************************************************
*
* Appendix Table A6, Individual campaign treatment index items
*
******************************************************************/

tokenize "pt_gotmoney;pt_gotface;pt_gotphone;pt_gotmail" , parse(";")

forvalues i = 1(1)4 {

 if `i'==1 {
  regress `1' treat pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
  outreg using "logs\TableA6.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace
 }
 else {
  regress `1' pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 interest pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
  outreg using "logs\TableA6.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append
 }

 mac shift
 mac shift

} 

restore

/******************************************************************
*
* Table 7, Treatment effect on partisanship and attitudes among pure independents
*
******************************************************************/

gen post_isindept=0 if pt_pid7~=.
replace post_isindept = 1 if pt_pid7==4
label var post_isindept "Pure independent in post survey (1=yes)"

gen post_viewbothparties=pt_evaldem+pt_evalrep
label var post_viewbothparties "Cumulate view both parties (-4=Strong Neg. both, 4=Very Pos. both)"

preserve

*Set common sample for below regressions
quietly regress post_isindept post_viewbothparties treat if (strata==14) & R_STRATACOAFILTER==0, robust
quietly keep if e(sample)

*summ post_isindept post_viewbothparties treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996

regress post_isindept treat if (strata==14) & R_STRATACOAFILTER==0, robust
outreg using "logs\Table7.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes replace 

regress post_isindept treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if (strata==14) & R_STRATACOAFILTER==0, robust
outreg using "logs\Table7.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress post_viewbothparties treat if (strata==14) & R_STRATACOAFILTER==0, robust
outreg using "logs\Table7.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

regress post_viewbothparties treat age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 if (strata==14) & R_STRATACOAFILTER==0, robust
outreg using "logs\Table7.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

ivregress 2sls post_viewbothparties (post_isindept=treat) if (strata==14) & R_STRATACOAFILTER==0, robust
outreg using "logs\Table7.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

ivregress 2sls post_viewbothparties age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 (post_isindept=treat) if (strata==14) & R_STRATACOAFILTER==0, robust
outreg using "logs\Table7.out", se bfmt(fc) bdec(3) tdec(3) xstat bracket coefastr 3aster nonotes append 

restore

/******************************************************************
*
* Table A3, summary stats for outcomes among latent partisans
*
******************************************************************/

outsum pt_id_with_lean pt_direct_pid7 post_reg_lean  voted2008  pt_voteevalalignindex pt_voteevalalignindexwithcb pt_voteevalalignindexwitcbhist pt_policyevalalignindex pt_soughtinfo pt_persuadeothers pt_campaigndonation pt_interest treatmentindex if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5) using logs\TableA3.out, replace bracket

/******************************************************************
*
* Footnote 24 analysis: treatment effects on PID and voteeval index broken down by education/interest
*
******************************************************************/

gen treat_educ123=treat*((pt_educ==1) | (pt_educ==2) | (pt_educ==3))
gen treat_educ4=treat*(pt_educ==4)
gen treat_educ5=treat*(pt_educ==5)
tab pt_educ, gen(ed_dum_)
drop ed_dum_1 ed_dum_2 ed_dum_3

gen treat_interest01=treat*((interest==0) | (interest==1))
gen treat_interest2=treat*(interest==2)
gen interest_dum2=(interest==2)
label var interest_dum2 "Interest=2"

*By interest
regress pt_id_with_lean pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp interest_dum* treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
regress pt_id_with_lean pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp interest_dum* treat_interest*  if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp interest_dum* treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp interest_dum* treat_interest* if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust

*By education
regress pt_id_with_lean pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp ed_dum_* treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
regress pt_id_with_lean pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp ed_dum_* treat_educ* if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp ed_dum_* treat if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust
regress pt_voteevalalignindex pre_lean_dem age age2 regyear regyearmissing twonames combined_female voted2006-voted1996 pre_aligned_vh pre_direct_unemp pre_direct_econ pre_direct_bushap pre_direct_congapp ed_dum_* treat_educ* if R_STRATACOAFILTER==0 & (pid7==3 | pid7==5), robust


